@@ -18,6 +18,8 @@
 #include <QWidget>
 #endif
 
+#include <array>
+
 // BEGIN StateEffects
 class StateEffects
 {
@@ -165,7 +167,8 @@ struct DecoDefaultColors {
 };
 
 // clang-format off
-// these numbers come from the Breeze color scheme ([breeze]/colors/Breeze.colors)
+// These numbers come from the default color scheme which is currently
+// Breeze Light ([breeze repo]/colors/BreezeLight.colors)
 static const SetDefaultColors defaultViewColors = {
     { 255, 255, 255 }, // Background
     { 247, 247, 247 }, // Alternate
@@ -288,11 +291,15 @@ public:
     QBrush foreground(KColorScheme::ForegroundRole) const;
     QBrush decoration(KColorScheme::DecorationRole) const;
     qreal contrast() const;
-private:
-    struct {
-        QBrush fg[KColorScheme::NForegroundRoles];
-        QBrush bg[KColorScheme::NBackgroundRoles];
-        QBrush deco[KColorScheme::NDecorationRoles];
+
+    struct Brushes {
+        std::array<QBrush, KColorScheme::NForegroundRoles> fg;
+        std::array<QBrush, KColorScheme::NForegroundRoles> bg;
+        std::array<QBrush, KColorScheme::NForegroundRoles> deco;
+
+        bool operator==(const Brushes &b) const {
+            return this == &b || (fg == b.fg && bg == b.bg && deco == b.deco);
+        }
     } _brushes;
     qreal _contrast;
 
@@ -553,6 +560,14 @@ KColorScheme::KColorScheme(QPalette::ColorGroup state, ColorSet set, KSharedConf
     }
 }
 
+bool KColorScheme::operator==(const KColorScheme &other) const
+{
+    return d == other.d
+        || (d->_contrast == other.d->_contrast
+            && d->_brushes == other.d->_brushes)
+    ;
+}
+
 // static
 int KColorScheme::contrast()
 {
