@@ -57,7 +57,7 @@ class KCONFIGWIDGETS_EXPORT KColorSchemeManager : public QObject
     Q_OBJECT
 public:
     explicit KColorSchemeManager(QObject *parent = nullptr);
-    virtual ~KColorSchemeManager();
+    ~KColorSchemeManager() override;
 
     /**
      * A QAbstractItemModel of all available color schemes.
@@ -106,7 +106,7 @@ public:
     /**
      * Overload for createSchemeSelectionMenu(const QIcon &icon, const QString &text, const QString &selectedSchemeName, QObject *parent).
      *
-     * Since 5.67 sets the icon to theme id "preferences-desktop-color" and the text to "Color Scheme", before set a null icon and an emoty string.
+     * Since 5.67 sets the icon to theme id "preferences-desktop-color" and the text to "Color Scheme", before set a null icon and an empty string.
      */
     KActionMenu *createSchemeSelectionMenu(const QString &selectedSchemeName, QObject *parent);
     /**
@@ -117,6 +117,22 @@ public:
      * @since 5.67
      */
     KActionMenu *createSchemeSelectionMenu(QObject *parent);
+    /**
+     * Saves the color scheme to config file. The scheme is saved by default whenever it's changed.
+     * Use this method when autosaving is turned off, see setAutosaveChanges().
+     *
+     * @since 5.89
+     */
+    void saveSchemeToConfigFile(const QString &schemeName) const;
+    /**
+     * Sets color scheme autosaving. Default value is @c true.
+     * If this is set to @c false, the scheme is not going to be remembered when the
+     * application is restarted.
+     *
+     * @param autosaveChanges Enables/Disables autosaving of the color scheme.
+     * @since 5.89
+     */
+    void setAutosaveChanges(bool autosaveChanges);
 
 public Q_SLOTS:
     /**
@@ -132,6 +148,8 @@ public Q_SLOTS:
     void activateScheme(const QModelIndex &index);
 
 private:
+    QModelIndex indexForSchemeId(const QString &id) const;
+
     std::unique_ptr<KColorSchemeManagerPrivate> const d;
 };
 
