@@ -13,6 +13,7 @@
 #include <KAboutData>
 #include <KAcceleratorManager>
 #include <KLocalizedString>
+#include <KStandardShortcutWatcher>
 #include <QGuiApplication>
 #include <QLayout>
 #include <QMainWindow>
@@ -22,13 +23,30 @@
 
 namespace KStandardAction
 {
-AutomaticAction::AutomaticAction(const QIcon &icon, const QString &text, const QList<QKeySequence> &shortcut, const char *slot, QObject *parent)
+AutomaticAction::AutomaticAction(const QIcon &icon,
+                                 const QString &text,
+                                 KStandardShortcut::StandardShortcut standardShortcut,
+                                 const char *slot,
+                                 QObject *parent)
     : QAction(parent)
 {
     setText(text);
     setIcon(icon);
+
+    const QList<QKeySequence> shortcut = KStandardShortcut::shortcut(standardShortcut);
     setShortcuts(shortcut);
     setProperty("defaultShortcuts", QVariant::fromValue(shortcut));
+    connect(KStandardShortcut::shortcutWatcher(),
+            &KStandardShortcut::StandardShortcutWatcher::shortcutChanged,
+            this,
+            [standardShortcut, this](KStandardShortcut::StandardShortcut id, const QList<QKeySequence> &newShortcut) {
+                if (id != standardShortcut) {
+                    return;
+                }
+                setShortcuts(newShortcut);
+                setProperty("defaultShortcuts", QVariant::fromValue(newShortcut));
+            });
+
     connect(this, SIGNAL(triggered()), this, slot);
 }
 
@@ -165,10 +183,10 @@ QAction *_k_createInternal(StandardAction id, QObject *parent)
             if (appDisplayName.isEmpty()) {
                 appDisplayName = QCoreApplication::applicationName();
             }
-            sLabel = i18n(pInfo->psLabel, appDisplayName);
+            sLabel = pInfo->psLabel.subs(appDisplayName).toString();
         } break;
         default:
-            sLabel = i18n(pInfo->psLabel);
+            sLabel = pInfo->psLabel.toString();
         }
 
         if (QGuiApplication::isRightToLeft()) {
@@ -298,8 +316,8 @@ QAction *_k_createInternal(StandardAction id, QObject *parent)
             break;
         }
 
-        if (pInfo->psToolTip) {
-            pAction->setToolTip(i18n(pInfo->psToolTip));
+        if (!pInfo->psToolTip.isEmpty()) {
+            pAction->setToolTip(pInfo->psToolTip.toString());
         }
         pAction->setIcon(icon);
 
@@ -309,6 +327,16 @@ QAction *_k_createInternal(StandardAction id, QObject *parent)
             pAction->setShortcuts(cut);
             pAction->setProperty("defaultShortcuts", QVariant::fromValue(cut));
         }
+        pAction->connect(KStandardShortcut::shortcutWatcher(),
+                         &KStandardShortcut::StandardShortcutWatcher::shortcutChanged,
+                         pAction,
+                         [pAction, shortcut = pInfo->idAccel](KStandardShortcut::StandardShortcut id, const QList<QKeySequence> &newShortcut) {
+                             if (id != shortcut) {
+                                 return;
+                             }
+                             pAction->setShortcuts(newShortcut);
+                             pAction->setProperty("defaultShortcuts", QVariant::fromValue(newShortcut));
+                         });
 
         pAction->setObjectName(pInfo->psName);
     }
@@ -592,11 +620,11 @@ static QAction *buildAutomaticAction(QObject *parent, StandardAction id, const c
         return nullptr;
     }
 
-    AutomaticAction *action = new AutomaticAction(QIcon::fromTheme(p->psIconName), i18n(p->psLabel), KStandardShortcut::shortcut(p->idAccel), slot, parent);
+    AutomaticAction *action = new AutomaticAction(QIcon::fromTheme(p->psIconName), p->psLabel.toString(), p->idAccel, slot, parent);
 
     action->setObjectName(p->psName);
-    if (p->psToolTip) {
-        action->setToolTip(i18n(p->psToolTip));
+    if (!p->psToolTip.isEmpty()) {
+        action->setToolTip(p->psToolTip.toString());
     }
 
     if (parent && parent->inherits("KActionCollection")) {
