@@ -10,29 +10,30 @@
 #include "ktipdialog.h"
 #include "kconfigwidgets_debug.h"
 
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 83)
+
 #include <QApplication>
-#include <QFile>
 #include <QCheckBox>
+#include <QFile>
+#include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QLabel>
-#include <QDesktopWidget>
 #include <QPushButton>
 #include <QRandomGenerator>
+#include <QRegularExpression>
 #include <QScreen>
 #include <QTextBrowser>
-#include <QHBoxLayout>
-#include <QRegularExpression>
 #include <QVBoxLayout>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KSharedConfig>
 #include <KRandom>
 #include <KSeparator>
+#include <KSharedConfig>
 #include <KStandardGuiItem>
 
-class Q_DECL_HIDDEN KTipDatabase::Private
+class KTipDatabasePrivate
 {
 public:
     void loadTips(const QString &tipFile);
@@ -42,7 +43,7 @@ public:
     int currentTip;
 };
 
-void KTipDatabase::Private::loadTips(const QString &tipFile)
+void KTipDatabasePrivate::loadTips(const QString &tipFile)
 {
     tips.clear();
     addTips(tipFile);
@@ -53,7 +54,7 @@ void KTipDatabase::Private::loadTips(const QString &tipFile)
  * preparetips5, which depends on extracting exactly the same
  * text as done here.
  */
-void KTipDatabase::Private::addTips(const QString &tipFile)
+void KTipDatabasePrivate::addTips(const QString &tipFile)
 {
     const QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, tipFile);
 
@@ -78,9 +79,7 @@ void KTipDatabase::Private::addTips(const QString &tipFile)
          * To make translations work, tip extraction here must exactly
          * match what is done by the preparetips5 script.
          */
-        QString tip = content
-                      .mid(pos + 6, content.indexOf(QLatin1String("</html>"), pos, Qt::CaseInsensitive) - pos - 6)
-                      .replace(rx, QStringLiteral("\n"));
+        QString tip = content.mid(pos + 6, content.indexOf(QLatin1String("</html>"), pos, Qt::CaseInsensitive) - pos - 6).replace(rx, QStringLiteral("\n"));
 
         if (!tip.endsWith('\n')) {
             tip += '\n';
@@ -102,7 +101,7 @@ void KTipDatabase::Private::addTips(const QString &tipFile)
 }
 
 KTipDatabase::KTipDatabase(const QString &_tipFile)
-    : d(new Private)
+    : d(new KTipDatabasePrivate)
 {
     QString tipFile = _tipFile;
 
@@ -118,7 +117,7 @@ KTipDatabase::KTipDatabase(const QString &_tipFile)
 }
 
 KTipDatabase::KTipDatabase(const QStringList &tipsFiles)
-    : d(new Private)
+    : d(new KTipDatabasePrivate)
 {
     if (tipsFiles.isEmpty() || ((tipsFiles.count() == 1) && tipsFiles.first().isEmpty())) {
         d->addTips(QCoreApplication::applicationName() + QStringLiteral("/tips"));
@@ -133,10 +132,7 @@ KTipDatabase::KTipDatabase(const QStringList &tipsFiles)
     }
 }
 
-KTipDatabase::~KTipDatabase()
-{
-    delete d;
-}
+KTipDatabase::~KTipDatabase() = default;
 
 void KTipDatabase::nextTip()
 {
@@ -170,17 +166,17 @@ QString KTipDatabase::tip() const
         return QString();
     }
 
-    return d->tips[ d->currentTip ];
+    return d->tips[d->currentTip];
 }
 
-class Q_DECL_HIDDEN KTipDialog::Private
+class KTipDialogPrivate
 {
 public:
-    Private(KTipDialog *_parent)
-        : parent(_parent)
+    KTipDialogPrivate(KTipDialog *qq)
+        : q(qq)
     {
     }
-    ~Private()
+    ~KTipDialogPrivate()
     {
         delete database;
     }
@@ -189,7 +185,7 @@ public:
     void _k_prevTip();
     void _k_showOnStart(bool);
 
-    KTipDialog *parent;
+    KTipDialog *const q;
     KTipDatabase *database;
     QCheckBox *tipOnStart;
     QTextBrowser *tipText;
@@ -197,30 +193,28 @@ public:
     static KTipDialog *mInstance;
 };
 
-KTipDialog *KTipDialog::Private::mInstance = nullptr;
+KTipDialog *KTipDialogPrivate::mInstance = nullptr;
 
-void KTipDialog::Private::_k_prevTip()
+void KTipDialogPrivate::_k_prevTip()
 {
     database->prevTip();
-    tipText->setHtml(QStringLiteral("<html><body>%1</body></html>")
-                     .arg(i18nd(KLocalizedString::applicationDomain(), database->tip().toUtf8())));
+    tipText->setHtml(QStringLiteral("<html><body>%1</body></html>").arg(i18nd(KLocalizedString::applicationDomain(), database->tip().toUtf8())));
 }
 
-void KTipDialog::Private::_k_nextTip()
+void KTipDialogPrivate::_k_nextTip()
 {
     database->nextTip();
-    tipText->setHtml(QStringLiteral("<html><body>%1</body></html>")
-                     .arg(i18nd(KLocalizedString::applicationDomain(), database->tip().toUtf8())));
+    tipText->setHtml(QStringLiteral("<html><body>%1</body></html>").arg(i18nd(KLocalizedString::applicationDomain(), database->tip().toUtf8())));
 }
 
-void KTipDialog::Private::_k_showOnStart(bool on)
+void KTipDialogPrivate::_k_showOnStart(bool on)
 {
-    parent->setShowOnStart(on);
+    q->setShowOnStart(on);
 }
 
 KTipDialog::KTipDialog(KTipDatabase *database, QWidget *parent)
-    : QDialog(parent),
-      d(new Private(this))
+    : QDialog(parent)
+    , d(new KTipDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Tip of the Day"));
 
@@ -280,8 +274,7 @@ KTipDialog::KTipDialog(KTipDatabase *database, QWidget *parent)
         QScreen *screen = QGuiApplication::screenAt(QCursor::pos());
         if (screen) {
             const QRect rect = screen->geometry();
-            move(rect.x() + (rect.width() - sh.width()) / 2,
-                    rect.y() + (rect.height() - sh.height()) / 2);
+            move(rect.x() + (rect.width() - sh.width()) / 2, rect.y() + (rect.height() - sh.height()) / 2);
         }
     }
 
@@ -313,10 +306,16 @@ KTipDialog::KTipDialog(KTipDatabase *database, QWidget *parent)
     KConfigGroup config(KSharedConfig::openConfig(), "TipOfDay");
     d->tipOnStart->setChecked(config.readEntry("RunOnStart", true));
 
-    connect(next, &QPushButton::clicked, this, [this]() { d->_k_nextTip(); });
-    connect(prev, &QPushButton::clicked, this, [this]() { d->_k_prevTip(); });
+    connect(next, &QPushButton::clicked, this, [this]() {
+        d->_k_nextTip();
+    });
+    connect(prev, &QPushButton::clicked, this, [this]() {
+        d->_k_prevTip();
+    });
     connect(ok, &QAbstractButton::clicked, this, &QDialog::accept);
-    connect(d->tipOnStart, &QCheckBox::toggled, this, [this](bool state) { d->_k_showOnStart(state); });
+    connect(d->tipOnStart, &QCheckBox::toggled, this, [this](bool state) {
+        d->_k_showOnStart(state);
+    });
 
     ok->setFocus();
 
@@ -325,10 +324,9 @@ KTipDialog::KTipDialog(KTipDatabase *database, QWidget *parent)
 
 KTipDialog::~KTipDialog()
 {
-    if (Private::mInstance == this) {
-        Private::mInstance = nullptr;
+    if (KTipDialogPrivate::mInstance == this) {
+        KTipDialogPrivate::mInstance = nullptr;
     }
-    delete d;
 }
 
 /**
@@ -375,17 +373,17 @@ void KTipDialog::showMultiTip(QWidget *parent, const QStringList &tipFiles, bool
           return; // Don't show tip on first start*/
     }
 
-    if (!Private::mInstance) {
-        Private::mInstance = new KTipDialog(new KTipDatabase(tipFiles), parent);
+    if (!KTipDialogPrivate::mInstance) {
+        KTipDialogPrivate::mInstance = new KTipDialog(new KTipDatabase(tipFiles), parent);
     } else
-        // The application might have changed the RunOnStart option in its own
-        // configuration dialog, so we should update the checkbox.
+    // The application might have changed the RunOnStart option in its own
+    // configuration dialog, so we should update the checkbox.
     {
-        Private::mInstance->d->tipOnStart->setChecked(runOnStart);
+        KTipDialogPrivate::mInstance->d->tipOnStart->setChecked(runOnStart);
     }
 
-    Private::mInstance->show();
-    Private::mInstance->raise();
+    KTipDialogPrivate::mInstance->show();
+    KTipDialogPrivate::mInstance->raise();
 }
 
 void KTipDialog::setShowOnStart(bool on)
@@ -396,9 +394,8 @@ void KTipDialog::setShowOnStart(bool on)
 
 bool KTipDialog::eventFilter(QObject *object, QEvent *event)
 {
-    if (object == d->tipText && event->type() == QEvent::KeyPress &&
-            (((QKeyEvent *)event)->key() == Qt::Key_Return ||
-             ((QKeyEvent *)event)->key() == Qt::Key_Space)) {
+    if (object == d->tipText && event->type() == QEvent::KeyPress
+        && (((QKeyEvent *)event)->key() == Qt::Key_Return || ((QKeyEvent *)event)->key() == Qt::Key_Space)) {
         accept();
     }
 
@@ -414,3 +411,4 @@ bool KTipDialog::eventFilter(QObject *object, QEvent *event)
 }
 
 #include "moc_ktipdialog.cpp"
+#endif
